#!/bin/sh -e
### BEGIN INIT INFO
# Provides:          looksgood
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the looksgood
### END INIT INFO

NAME=media-cast
PKG_PATH=/usr/local/AppCentral/$NAME
WEB_BROWSER_PATH=/usr/local/AppCentral/web-browser
PID_PATH=$PKG_PATH/pid
LOG_PATH=$PKG_PATH/log
TMP_PATH=$PKG_PATH/tmp

SEQ_START="ascast"
SEQ_STOP="ascast"

if [ ! -e $PKG_PATH/CONTROL/env.sh ]; then
    echo "Can't find $PKG_PATH/CONTROL/env.sh"
    exit 1
fi

source $PKG_PATH/CONTROL/env.sh

. /lib/lsb/init-functions



start_daemon () {

    echo 'starting >>'

    #leapcast
    [ -f $PKG_PATH/bin/leapcast ] && python $PKG_PATH/bin/leapcast --name `hostname` --chrome $WEB_BROWSER_PATH/chromium/run_chromium.sh >/dev/null 2>&1 &


    #clean $TMP_PATH
    rm -rf $TMP_PATH/*

    for srv in $SEQ_START;
    do
        if [ -e "$PID_PATH/$srv.pid" ]; then
            echo "Service: $srv exists!"
            continue
        fi

        if [ ! -e "$PKG_PATH/bin/$srv/$srv.pyc" ]; then
            echo "Service: $srv binary don't exist!"
            continue
        fi

        #save old log
        [ -e $LOG_PATH/$srv.log ] && mv $LOG_PATH/$srv.log $LOG_PATH/$srv.log.old

        #start daemons
        python $PKG_PATH/bin/$srv/$srv.pyc start &

    done

    #check if daemon is started or not
    for srv in $SEQ_START;
    do
        if [ ! -e "$PKG_PATH/bin/$srv/$srv.pyc" ]; then
            continue
        fi

        #countdown 10 sec.
        i=10
        while [ $i -gt 0 ];
        do
            echo "$srv Count: $i"

            i=$(($i - 1))
            if [ $i -eq 0 ]; then
                echo "Start service: $srv failed!"
            else
                sleep 1
            fi

            if [ -e "$PID_PATH/$srv.pid" ]; then
                echo "Start service: $srv successfully!"
                break
            fi

        done
    done

    echo 'starting <<'
}

stop_daemon () {
    echo 'stopping >>'

    #leapcast
    for pid in $(ps | grep "$PKG_PATH/bin/leapcast" | grep -v "grep" | awk '{print $1}');
    do
        kill -9 $pid & > /dev/null
    done

    for srv in $SEQ_STOP;
    do
        if [ ! -e "$PKG_PATH/bin/$srv/$srv.pyc" ]; then
            echo "Service: $srv binary don't exist!"
            continue
        fi
        [ -e "$PID_PATH/$srv.pid" ] && python $PKG_PATH/bin/$srv/$srv.pyc stop &
    done

    #check if daemon is stopped or not
    for srv in $SEQ_STOP;
    do
        if [ ! -e "$PKG_PATH/bin/$srv/$srv.pyc" ]; then
            continue
        fi

        if [ ! -e "$PID_PATH/$srv.pid" ]; then
            echo "service: $srv had been stopped!"
            continue
        fi

        #countdown 10 sec., then kill service forcibly.
        i=10
        while [ $i -gt 0 ];
        do
            echo "$srv Count: $i"

            i=$(($i - 1))
            if [ $i -eq 0 ]; then
                echo "Stop service: $srv forcibly!"
                kill -9 $(cat $PID_PATH/$srv.pid) && rm $PID_PATH/$srv.pid || echo "Stop service: $srv failed!"
            else
                sleep 1
            fi

            if [ ! -e "$PID_PATH/$srv.pid" ]; then
                echo "Stop service: $srv successfully!"
                break
            fi

        done

    done

    #python-airplay will create process to listen event, sometimes the processes still is alive
    for pid in $(ps | grep "$PKG_PATH/bin/ascast/ascast.pyc" | grep -v "grep" | awk '{print $1}');
    do
        kill -9 $pid & > /dev/null
    done

    #clean $TMP_PATH
    rm -rf $TMP_PATH/*

    echo 'stopping <<'
}

suspend_daemon () {

    for srv in $SEQ_STOP;
    do
        [ -e "$PID_PATH/$srv.pid" ] && python $PKG_PATH/bin/$srv/$srv.pyc suspend &
    done


}


case $1 in
    "start")
        echo "Starting daemon" "$NAME..."
        stop_daemon
        echo "======================================================"
        start_daemon

        ;;
    "stop")
        echo "Stopping daemon" "$NAME..."
        stop_daemon

        ;;
    "suspend")
        echo "Suspending daemon" "$NAME..."
        suspend_daemon

        ;;
    "restart")
        echo "Restarting daemon" "$NAME..."
        stop_daemon
        echo "======================================================"
        start_daemon

        ;;
    *)
        echo "Usage: /etc/init.d/$NAME {start|resume|stop|suspend|restart}"
        logger_daemon_msg "*"
        exit 2
        ;;
esac

exit 0


